@@ -1,4 +1,8 @@
 package CodeGen::Cpppp::AntiCharacter;
+
+our $VERSION = '0.001_05'; # TRIAL VERSION
+# ABSTRACT: AntiCharacters combine with characters to produce nothing
+
 use v5.20;
 use warnings;
 use Carp;
@@ -49,11 +53,11 @@ __END__
 
 =head1 NAME
 
-CodeGen::Cpppp::AntiCharacter
+CodeGen::Cpppp::AntiCharacter - AntiCharacters combine with characters to produce nothing
 
 =head1 VERSION
 
-version 0.001_04
+version 0.001_05
 
 =head1 AUTHOR
 
