@@ -1,11 +1,14 @@
 package CodeGen::Cpppp::Output;
-$INC{'CodeGen/Cpppp/Output.pm'}= 1;
+
+our $VERSION = '0.001_05'; # TRIAL VERSION
+# ABSTRACT: Collect text output into named sections
+
 use v5.20;
 use warnings;
+use experimental 'signatures', 'postderef';
 use Carp;
 use Scalar::Util 'looks_like_number';
 use List::Util 'max';
-use experimental 'signatures';
 
 
 our %standard_sections= (
@@ -108,11 +111,11 @@ __END__
 
 =head1 NAME
 
-CodeGen::Cpppp::Output
+CodeGen::Cpppp::Output - Collect text output into named sections
 
 =head1 VERSION
 
-version 0.001_04
+version 0.001_05
 
 =head1 DESCRIPTION
 
